@@ -58,6 +58,7 @@ struct KStandardShortcutInfo {
 #define ALT(x) QKeyCombination(Qt::ALT | Qt::Key_##x).toCombined()
 #define ALTSHIFT(x) QKeyCombination(Qt::ALT | Qt::SHIFT | Qt::Key_##x).toCombined()
 #define CTRLMETA(x) QKeyCombination(Qt::CTRL | Qt::META | Qt::Key_##x).toCombined()
+#define META(x) QKeyCombination(Qt::META | Qt::Key_##x).toCombined()
 
 /* Array of predefined KStandardShortcutInfo objects, which cover all
     the "standard" accelerators. Each enum value from StandardShortcut
@@ -65,6 +66,7 @@ struct KStandardShortcutInfo {
 */
 // STUFF WILL BREAK IF YOU DON'T READ THIS!!!
 // Read the comments of the big enum in kstandardshortcut.h before you change anything!
+// clazy:exclude-next-line=non-pod-global-static
 static KStandardShortcutInfo g_infoStandardShortcut[] = {
     // Group File,
     {AccelNone, nullptr, {nullptr, nullptr}, 0, 0, QList<QKeySequence>(), false, Category::InvalidCategory},
@@ -120,7 +122,18 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
      Category::Edit},
 
     {Find, "Find", QT_TRANSLATE_NOOP3("KStandardShortcut", "Find", "@action"), CTRL(F), 0, QList<QKeySequence>(), false, Category::Edit},
-    {FindNext, "FindNext", QT_TRANSLATE_NOOP3("KStandardShortcut", "Find Next", "@action"), Qt::Key_F3, 0, QList<QKeySequence>(), false, Category::Edit},
+    {FindNext,
+     "FindNext",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Find Next", "@action"),
+#if defined(Q_OS_MACOS)
+     CTRL(G),
+#else
+     Qt::Key_F3,
+#endif
+     0,
+     QList<QKeySequence>(),
+     false,
+     Category::Edit},
     {FindPrev, "FindPrev", QT_TRANSLATE_NOOP3("KStandardShortcut", "Find Prev", "@action"), SHIFT(F3), 0, QList<QKeySequence>(), false, Category::Edit},
     {Replace, "Replace", QT_TRANSLATE_NOOP3("KStandardShortcut", "Replace", "@action"), CTRL(R), 0, QList<QKeySequence>(), false, Category::Edit},
 
@@ -168,11 +181,26 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
      Category::Navigation},
 
     {Up, "Up", QT_TRANSLATE_NOOP3("KStandardShortcut", "Up", "@action"), ALT(Up), 0, QList<QKeySequence>(), false, Category::Navigation},
-    {Back, "Back", QT_TRANSLATE_NOOP3("KStandardShortcut", "Back", "@action"), ALT(Left), Qt::Key_Back, QList<QKeySequence>(), false, Category::Navigation},
+    {Back,
+     "Back",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Back", "@action"),
+#if defined(Q_OS_MACOS)
+     0,
+#else
+     ALT(Left),
+#endif
+     Qt::Key_Back,
+     QList<QKeySequence>(),
+     false,
+     Category::Navigation},
     {Forward,
      "Forward",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Forward", "@action"),
+#if defined(Q_OS_MACOS)
+     0,
+#else
      ALT(Right),
+#endif
      Qt::Key_Forward,
      QList<QKeySequence>(),
      false,
@@ -210,7 +238,18 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
      QList<QKeySequence>(),
      false,
      Category::Navigation},
-    {GotoLine, "GotoLine", QT_TRANSLATE_NOOP3("KStandardShortcut", "Go to Line", "@action"), CTRL(G), 0, QList<QKeySequence>(), false, Category::Navigation},
+    {GotoLine,
+     "GotoLine",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "Go to Line", "@action"),
+#if defined(Q_OS_MACOS)
+     META(G), // Ctrl+G on macos
+#else
+     CTRL(G),
+#endif
+     0,
+     QList<QKeySequence>(),
+     false,
+     Category::Navigation},
     {BackwardWord,
      "BackwardWord",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Backward Word", "@action"),
@@ -293,7 +332,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {PrevCompletion,
      "PrevCompletion",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Previous Completion Match", "@action"),
+#if defined(Q_OS_MACOS)
+     0,
+#else
      CTRL(Up),
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -301,7 +344,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {NextCompletion,
      "NextCompletion",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Next Completion Match", "@action"),
+#if defined(Q_OS_MACOS)
+     0,
+#else
      CTRL(Down),
+#endif
      0,
      QList<QKeySequence>(),
      false,
